<?php
namespace App\Http\Controllers;

use Illuminate\Http\Request;
use Illuminate\Support\Facades\Http;
use Illuminate\Support\Str;
use Illuminate\Support\Facades\Mail;
use App\Mail\SendMail;
use DB;
use Illuminate\Support\Facades\Session;
use Carbon\Carbon;
use App\Helpers\Helper;
use Stripe\Stripe;
use Stripe\Customer;
use Stripe\PaymentIntent;
use Stripe\EphemeralKey;

class ApiController extends Controller{
    
  /* SEND NOTIFICATIONS */
  public function send_notification($data){
    DB::table('notifications')->insert($data);
  }
  /* SEND NOTIFICATIONS */
  
  function calculate_distance($lat_from , $long_from , $lat_to , $long_to , $unit = 'Miles'){
    $radius_unit  = DB::table('system_settings')->select('description')->where('type', 'radius_unit')->get()->first();
    $unit = $radius_unit ? $radius_unit->description : $unit;  

    $theta = $long_to - $long_from;
    $distance = sin(deg2rad($lat_from)) * sin(deg2rad($lat_to)) + cos(deg2rad($lat_from)) * cos(deg2rad($lat_to)) * cos(deg2rad($theta));
    $distance = acos($distance);
    $distance = rad2deg($distance);
    $miles = $distance * 60 * 1.1515; 

    // echo "Theta: $theta, Distance (radians): $distance, Distance (miles): $miles\n";

    if ($unit == 'KM') {
        return number_format((float)($miles * 1.609344), 2, '.', '');
    } else if ($unit == 'N') {
        return number_format((float)($miles * 0.8684), 2, '.', '');
    } else if ($unit == 'Miles') {
        return number_format((float)$miles, 2, '.', '');
    } else {
        return '1.2 Miles';
    }
  }

  /* GET SYSTEM SETTINGS */
  public function system_settings(){
    $system_settings   =  DB::table('system_settings')->get();
    if (!empty($system_settings)) {
      $response["code"] = 200;
      $response["status"] = "success";
      $response["data"] = $system_settings;
    } else {
      $response["code"] = 404;
      $response["status"] = "error";
      $response["message"] = "no data found.";
    }
    return response()
      ->json(array( 'status' => $response["status"], isset($response["message"]) ? 'message' : 'data' => isset($response["message"]) ? $response["message"] : $response["data"]))
      ->header('Content-Type', 'application/json');
  }
  /* GET SYSTEM SETTINGS */

  /* GET Notifications */
  public function notifications(Request $req){
    if(isset($req->users_customers_id)) {
      $notifications   =  DB::table('notifications')->where('receivers_id', $req->users_customers_id)->where('users_type' , 'Users')->get();
      $users_system   =  DB::table('users_system')->where('status', 'Active')->get();

      if (count($notifications) > 0) {
        $all_notifications = array(); 
        foreach($notifications as $notification){

          // //MY LIKES
          // $users_likes   =  DB::table('users_likes')->where('post_id', $notification->venues_id)->where('users_customers_id', $req->users_customers_id)->where('type', 'Venues')->get()->count();
          // $notification->likes = $users_likes;
          // //MY LIKES

          $all_notifications[] = $notification;
        }

        $response["code"] = 200;
        $response["status"] = "success";
        $response["data"] = $all_notifications;
      } else {
        $response["code"] = 404;
        $response["status"] = "error";
        $response["message"] = "no data found.";
      }
    } else {
      $response["code"] = 404;
      $response["status"] = "error";
      $response["message"] = "All fields are needed.";
    }

    return response()
      ->json(array( 'status' => $response["status"], isset($response["message"]) ? 'message' : 'data' => isset($response["message"]) ? $response["message"] : $response["data"]))
      ->header('Content-Type', 'application/json');
  }
  /* GET Notifications */

  /* GET CATEGORIES ALL */
  public function categories_all(Request $req){
    // Check if all required fields are present
    if(isset($req->users_customers_id) && isset($req->current_longitude) && isset($req->current_lattitude)) {
        // Fetch all active venues
        $categories = DB::table('categories')->where('status', 'Active')->get();

        // Prepare response
        if (count($categories) > 0) {
            $response = [
                "code" => 200,
                "status" => "success",
                "data" => $categories
            ];
        } else {
            $response = [
                "code" => 404,
                "status" => "error",
                "message" => "No Category Found"
            ];
        }
    } else {
        $response = [
            "code" => 404,
            "status" => "error",
            "message" => "All fields are needed."
        ];
    }

    return response()->json($response)->header('Content-Type', 'application/json');
  }
  /* GET CATEGORIES ALL */

  /* GET CATEGORIES */
  public function categories(Request $req){
    // Check if all required fields are present
    if(isset($req->users_customers_id) && isset($req->current_longitude) && isset($req->current_lattitude)) {
        // Fetch all active venues
        $categories = DB::table('categories')->where('parent_id', '0')->where('status', 'Active')->get();

        // Prepare response
        if (count($categories) > 0) {
            $response = [
                "code" => 200,
                "status" => "success",
                "data" => $categories
            ];
        } else {
            $response = [
                "code" => 404,
                "status" => "error",
                "message" => "No Category Found"
            ];
        }
    } else {
        $response = [
            "code" => 404,
            "status" => "error",
            "message" => "All fields are needed."
        ];
    }

    return response()->json($response)->header('Content-Type', 'application/json');
  }
  /* GET CATEGORIES */

  /* GET SUB CATEGORIES BY ID */
  public function categories_sub(Request $req){
    if(isset($req->categories_id)) {
      $categories         =  DB::table('categories')->where('parent_id', $req->categories_id)->get();

      if (!empty($categories[0])) {
        $response["code"] = 200;
        $response["status"] = "success";
        $response["data"] = $categories;
      } else {
        $response["code"] = 404;
        $response["status"] = "error";
        $response["message"] = "no data found.";
      }
    } else {
      $response["code"] = 404;
      $response["status"] = "error";
      $response["message"] = "All fields are needed.";
    }

    return response()
      ->json(array( 'status' => $response["status"], isset($response["message"]) ? 'message' : 'data' => isset($response["message"]) ? $response["message"] : $response["data"]))
      ->header('Content-Type', 'application/json');
  }
  /* GET SUB CATEGORIES BY ID */

  /* CHECK REFERRAL CODE */
  public function check_referral_code(Request $req){
    if (isset($req->referral_code)) {
      $referral_code  = base64_decode($req->referral_code);
      $exists         = DB::table('users_customers')->where('users_customers_id', $referral_code)->get()->count();
      
      if ($exists > 0) {
        $userDetail = DB::table('users_customers')->where('users_customers_id', $referral_code)->get()->first();
      
        if($userDetail->status == 'Active'){
          $response["code"] = 200;
          $response["status"] = "success";
          $response["data"] = $userDetail;
        } else {
          $response["code"] = 404;
          $response["status"] = "error";
          $response["message"] = "User Account is ." . $userDetail->status;
        } 
      } else {
        $response["code"] = 404;
        $response["status"] = "error";
        $response["message"] = "No user found for this referral code.";
      }
    } else {
      $response["code"] = 404;
      $response["status"] = "error";
      $response["message"] = "All fields are needed.";
    }

    return response()
    ->json(array( 'status' => $response["status"], isset($response["message"]) ? 'message' : 'data' => isset($response["message"]) ? $response["message"] : $response["data"]))
    ->header('Content-Type', 'application/json');
  }
  /* CHECK REFERRAL CODE */

  /* SIGNUP USERS CUSTOMERS */
  public function users_customers_signup(Request $req){
    if (isset($req->referral_users_customers_id) && isset($req->email) && isset($req->password) && isset($req->account_type) && isset($req->sur_name) && isset($req->first_name) && isset($req->last_name) && isset($req->one_signal_id) && isset($req->current_longitude) && isset($req->current_lattitude)) {
      $email = DB::table('users_customers')->where('email', $req->email)->get()->count();

      if($email == 0) {
        $randomString = Str::random(12);    
        $md5Token = md5($randomString);
        $auth_key = 'authentication_key_' .$md5Token;
        $data = array(
          'referral_users_customers_id'=>$req->referral_users_customers_id,
          'sur_name'=>$req->sur_name,
          'first_name'=>$req->first_name,
          'last_name'=>$req->last_name,
          'email'=>$req->email,
          'one_signal_id'=>$req->one_signal_id,
          'current_lattitude'=>$req->current_lattitude,
          'current_longitude'=>$req->current_longitude,
          'account_type'=>$req->account_type,
          'password'=> md5($req->password),
          'authentication_token'=> $auth_key,  
          'date_added'=>date('Y-m-d H:i:s'),
          'notifications'=>'Yes',
          'status'=>'Active'
        );

        $users_customers_id   = DB::table('users_customers')->insertGetId($data);
        $users_customers      = DB::table('users_customers')->where('users_customers_id', $users_customers_id)->get();
        $response["code"]     = 200;   
        $response["status"]   = "success";
        $response["data"]     = $users_customers;
      } else {
        $response["code"]     = 401;
        $response["status"]   = "error";
        $response["message"]  = "Email already exists.";
      }
    } else {
      $response["code"] = 404;
      $response["status"] = "error";
      $response["message"] = "All fields are needed.";
    }
    
    return response()
     ->json(array( 'status' => $response["status"], isset($response["message"]) ? 'message' : 'data' => isset($response["message"]) ? $response["message"] : $response["data"]))
     ->header('Content-Type', 'application/json');
  }
  /* SIGNUP USERS CUSTOMERS */
    
  /* LOGIN USERS CUSTOMERS */
  public function users_customers_login(Request $req){
    if (isset($req->email) && isset($req->password) && isset($req->one_signal_id) && isset($req->current_longitude) && isset($req->current_lattitude)) {
      $email = DB::table('users_customers')->where('email', $req->email)->get()->count();
      if ($email>0) {
        $data=DB::table('users_customers')->where('email', $req->email)->get();
        $password=$data[0]->password;
        $id = $data[0]->users_customers_id;
        if (md5($req->password) == $password) {
          $userDetail=DB::table('users_customers')->where('users_customers_id', $id)->get()->first();
          if (isset($userDetail) && $userDetail != null) {
            if($userDetail->status == 'Active'){
              // UPDATE LOCATION AND ONSINGNAL
              $updateData['one_signal_id']          = $req->one_signal_id;
              $updateData['current_longitude']      = $req->current_longitude;
              $updateData['current_lattitude']      = $req->current_lattitude;
              DB::table('users_customers')->where('users_customers_id', $id)->update($updateData);
              $updatedData = DB::table('users_customers')->where('users_customers_id', $id)->get();
              // UPDATE LOCATION AND ONSINGNAL
              
              $response["code"] = 200;
              $response["status"] = "success";
              $response["data"] = $updatedData;
            } else {
              $response["code"] = 404;
              $response["status"] = "error";
              $response["message"] = "User Account is inactive.";
            } 
          } else{
            $response["code"] = 404;
            $response["status"] = "error";
            $response["message"] = "User do not exist.";
          }
        } else {
          $response["code"] = 404;
          $response["status"] = "error";
          $response["message"] = "Password do not match.";
        }
      }else{
        $response["code"] = 404;
        $response["status"] = "error";
        $response["message"] = "Email does not exits.";
      }
    } else {
      $response["code"] = 404;
      $response["status"] = "error";
      $response["message"] = "All fields are needed.";
    }

    return response()
    ->json(array( 'status' => $response["status"], isset($response["message"]) ? 'message' : 'data' => isset($response["message"]) ? $response["message"] : $response["data"]))
    ->header('Content-Type', 'application/json');
  }
  /* LOGIN USERS CUSTOMERS */

  /* GET USERS CUSTOMERS */
  public function users_customers_profile(Request $req){
    if (isset($req->users_customers_id)) {
      $userDetail=DB::table('users_customers')->where('users_customers_id', $req->users_customers_id)->get()->first();
      if (isset($userDetail) && $userDetail != null) {
        $response["code"] = 200;
        $response["status"] = "success";
        $response["data"] = $userDetail;
      } else{
        $response["code"] = 404;
        $response["status"] = "error";
        $response["message"] = "User do not exist.";
      }
    } else {
      $response["code"] = 404;
      $response["status"] = "error";
      $response["message"] = "All fields are needed.";
    }

    return response()
    ->json(array( 'status' => $response["status"], isset($response["message"]) ? 'message' : 'data' => isset($response["message"]) ? $response["message"] : $response["data"]))
    ->header('Content-Type', 'application/json');
  } 
  /* GET USERS CUSTOMERS */

  /* UPDATE PROFILE */
  public function update_profile(Request $req){
    if(isset($req->users_customers_id) && isset($req->email) && isset($req->sur_name) && isset($req->first_name) && isset($req->last_name) && isset($req->age) && isset($req->notifications) && isset($req->current_longitude) && isset($req->current_lattitude)) {
      $updateData['users_customers_id'] = $req->users_customers_id;
      $updateData['sur_name']           = $req->sur_name;
      $updateData['first_name']         = $req->first_name;
      $updateData['last_name']          = $req->last_name;
      $updateData['email']              = $req->email;
      $updateData['age']                = $req->age;
      $updateData['notifications']      = $req->notifications;
      $updateData['current_longitude']  = $req->current_longitude;
      $updateData['current_lattitude']  = $req->current_lattitude;

      if(isset($req->profile_picture)){
        $profile_picture = $req->profile_picture;
        $prefix = time();
        $img_name = $prefix . '.jpeg';
        $image_path = public_path('uploads/users_customers/') . $img_name;

        file_put_contents($image_path, base64_decode($profile_picture));
        $updateData['profile_picture'] = 'uploads/users_customers/'. $img_name;
      }

      DB::table('users_customers')->where('users_customers_id', $req->users_customers_id)->update($updateData);
      $updatedData = DB::table('users_customers')->where('users_customers_id', $req->users_customers_id)->get();
 
      $response["code"] = 200;
      $response["status"] = "success";
      $response["data"] = $updatedData;
    } else {
      $response["code"] = 404;
      $response["status"] = "error";
      $response["message"] = "All fields are needed.";
    }

    return response()
      ->json(array( 'status' => $response["status"], isset($response["message"]) ? 'message' : 'data' => isset($response["message"]) ? $response["message"] : $response["data"]))
      ->header('Content-Type', 'application/json');
  }
  /* UPDATE PROFILE */

  //  update user location 
  public function update_location(Request $request){
    if (isset($request->users_customers_id) && isset($request->current_lattitude) && isset($request->current_longitude)) {
      $userCustomer = DB::table('users_customers')->where('users_customers_id',$request->users_customers_id)->first();

      if (!$userCustomer) {
          $response = [
              'code' => 404,
              'status' => 'error',
              'message' => 'User customer not found'
          ];
      } else {
          DB::table('users_customers')         
              ->where('users_customers_id',$request->users_customers_id)
              ->update([
                  'current_lattitude' => $request->current_lattitude,
                  'current_longitude' => $request->current_longitude    
              ]);

          $response = [
              'code' => 200,
              'status' => 'success',
              'message' => 'User location updated successfully'
          ];
      }
    } else  {
      $response["code"] = 404;
      $response["status"] = "error";
      $response["message"] = "All fields are needed";
    }

    return response()
    ->json(array('status' => $response["status"], isset($response["message"]) ? 'message' : 'data' => isset($response["message"]) ? $response["message"] : $response["data"]))
    ->header('Content-Type', 'application/json');
  }
  //  update user location 

  /* DELETE ACCOUNT API */
  public function delete_account(Request $req){
    if (isset($req->user_email) && isset($req->delete_reason) && isset($req->comments)) {
      $users_customers = DB::table('users_customers')->where('email', $req->user_email)->get()->count();
      if ($users_customers>0) {
        $users_customers_delete = DB::table('users_customers_delete')->where('email', $req->user_email)->get()->count();
        if ($users_customers_delete == 0) { 
          $data = array(
            'email'=>$req->user_email,
            'delete_reason'=> $req->delete_reason,
            'comments'=> $req->comments,
            'date_added'=>date('Y-m-d H:i:s'),
            'status'=>'Pending'
          );
          $users_customers_id   = DB::table('users_customers_delete')->insertGetId($data);

          $response["code"] = 200;
          $response["status"] = "success";
          $response["message"] = "Delete account request recieved successfully.";
        }else{
          $response["code"] = 404;
          $response["status"] = "error";
          $response["message"] = "Delete account request already sent. Please wait out team will get back to you in 24 hours.";
        }
      }else{
        $response["code"] = 404;
        $response["status"] = "error";
        $response["message"] = "Email does not exists.";
      }
    }else{
      $response["code"] = 404;
      $response["status"] = "error";
      $response["message"] = "All fields are required.";
    }
    
    return response()
      ->json(array( 'status' => $response["status"], isset($response["message"]) ? 'message' : 'data' => isset($response["message"]) ? $response["message"] : $response["data"]))
      ->header('Content-Type', 'application/json');
  }
  /* DELETE ACCOUNT API */

  /* FORGOT PASSWORD ACCOUNT API */
  public function forgot_password(Request $req){
    if (isset($req)) {
      $email = DB::table('users_customers')->where('email', $req->email)->get()->count();

      if ($email > 0) {
        // Retrieve the email template from the database based on type
        $template = DB::table('email_templates')
            ->where('type', 'forgot_password')      
            ->first();
    
        if (!$template) {
            $response["code"] = 404;
            $response["status"] = "error";
            $response["message"] = "Email template not found for forget password.";
            return response()
                ->json([
                    'status' => $response["status"],
                    'message' => $response["message"]
                ])
                ->header('Content-Type', 'application/json');
        }
    
        // Get user data
        $userData = DB::table('users_customers')->where('email', $req->email)->first();
    
        // Replace tags in the template with actual data
        $templateBody = str_replace('{first_name}', $userData->first_name, $template->body);
        $otp = rand(1000, 9999);
        $templateBody = str_replace('{otp}', $otp, $templateBody); // Assuming you want to replace the OTP
    
        $details = [
            "title" => $template->subject,
            "body" => $templateBody
        ];
    
        // Send email with the modified template
        $otpSended = Mail::to($req->email)->send(new SendMail($details));
    
        // Update the OTP in the database
        $UserotpUpdate = DB::table('users_customers')->where('users_customers_id', $userData->users_customers_id)
            ->update(['verify_code' => $otp]);
    
        $response["code"] = 200;
        $response["status"] = "success";
        $response["data"] = [
            'message' => 'OTP sent in the email.',
            'otp' => $otp // Include the OTP in the response
        ];
    } else {
        $response["code"] = 404;
        $response["status"] = "error";
        $response["message"] = "Email does not exist.";
    }
    
    return response()
        ->json([
            'status' => $response["status"],
            isset($response["message"]) ? 'message' : 'data' => isset($response["message"]) ? $response["message"] : $response["data"]
        ])
        ->header('Content-Type', 'application/json');
    }
  }
  /* FORGOT PASSWORD ACCOUNT API */

  /* MODIFY PASSWORD ACCOUNT API */
  public function modify_forgot_password(Request $req){
    if (isset($req->email) && isset($req->otp) && isset($req->password) && isset($req->confirm_password)) {
      $forgetOtp = DB::table('users_customers')->select('verify_code')->where('email', $req->email)->get();
      $otpforgetdb = $forgetOtp[0]->verify_code;
      if ($otpforgetdb == $req->otp) {
        if ($req->confirm_password == $req->password) {
          $otpData=array(
           'verify_code'=>'',
           'password' => md5($req->password)
          );
          
          $UserotpUpdate =DB::table('users_customers')->where('email', $req->email)->update($otpData);
          $users_customers = DB::table('users_customers')->where('email', $req->email)->get();
          
          $response["code"] = 200;
          $response["status"] = "success";
          $response["data"] = $users_customers;
        } else {
          $response["code"] = 404;
          $response["status"] = "error";
          $response["message"] = "Password and confirm password do not match.";
        }
      } else {
        $response["code"] = 404;
        $response["status"] = "error";
        $response["message"] = "Otp do not match.";
      }
    }else{
      $response["code"] = 404;
      $response["status"] = "error";
      $response["message"] = "All fields are required.";
    }
    
    return response()
     ->json(array( 'status' => $response["status"], isset($response["message"]) ? 'message' : 'data' => isset($response["message"]) ? $response["message"] : $response["data"]))
     ->header('Content-Type', 'application/json');
  }
  /* MODIFY PASSWORD ACCOUNT API */

  /* CHANGE PASSWORD ACCOUNT API */
  public function change_password(Request $req){
    if (isset($req->email) && isset($req->old_password) && isset($req->password) && isset($req->confirm_password)) {
      $old_password = DB::table('users_customers')->select('password')->where('email', $req->email)->get();
      $old_passwordDB = $old_password[0]->password;
      if ($old_passwordDB == md5($req->old_password)) {
        if ($req->confirm_password == $req->password) {
          $otpData=array('password' => md5($req->password));          
          $UserotpUpdate =DB::table('users_customers')->where('email', $req->email)->update($otpData);
          $users_customers = DB::table('users_customers')->where('email', $req->email)->get();
          
          $response["code"] = 200;
          $response["status"] = "success";
          $response["data"] = $users_customers;
        } else {
          $response["code"] = 404;
          $response["status"] = "error";
          $response["message"] = "Password and confirm password do not match.";
        }
      } else {
        $response["code"] = 404;
        $response["status"] = "error";
        $response["message"] = "Old password is not correct.";
      }
    }else{
      $response["code"] = 404;
      $response["status"] = "error";
      $response["message"] = "All fields are required.";
    }
    
    return response()
     ->json(array( 'status' => $response["status"], isset($response["message"]) ? 'message' : 'data' => isset($response["message"]) ? $response["message"] : $response["data"]))
     ->header('Content-Type', 'application/json');
  }
  /* CHANGE PASSWORD ACCOUNT API */
  
  /* GET THINGS */
  public function things(Request $req){
    // Check if all required fields are present
    if(isset($req->users_customers_id) && isset($req->current_longitude) && isset($req->current_lattitude)) {
        // Fetch all active venues
        $things = DB::table('things')->where('status', 'Active')->get();

        // Prepare response
        if (count($things) > 0) {
            $response = [
                "code" => 200,
                "status" => "success",
                "data" => $things
            ];
        } else {
            $response = [
                "code" => 404,
                "status" => "error",
                "message" => "No Things Found"
            ];
        }
    } else {
        $response = [
            "code" => 404,
            "status" => "error",
            "message" => "All fields are needed."
        ];
    }

    return response()->json($response)->header('Content-Type', 'application/json');
  }
  /* GET THINGS */
  
  /* THINGS ADD API */
  public function things_add(Request $req){
    if (
        isset($req->users_customers_id) && 
        isset($req->categories_id) && 
        isset($req->name) && 
        isset($req->earn_points) && 
        isset($req->location) && 
        isset($req->longitude) && 
        isset($req->lattitude) && 
        isset($req->google_place_id) && 
        isset($req->country) && 
        isset($req->state) && 
        isset($req->city) && 
        isset($req->post_code) && 
        isset($req->sources_links) && 
        isset($req->confirm_by_moderator) && 
        isset($req->description)
    ) {
        
        // print_r($req->tags);
        // print_r($req->images);
        // exit;
        
        $data['users_customers_id']     = $req->users_customers_id;
        $data['categories_id']          = $req->categories_id;

        $data['name']                   = $req->name;
        $data['earn_points']            = $req->earn_points;

        $data['location']               = $req->location;
        $data['longitude']              = $req->longitude;
        $data['lattitude']              = $req->lattitude;
        $data['google_place_id']        = $req->google_place_id;
        $data['country']                = $req->country;
        $data['state']                  = $req->state;
        $data['city']                   = $req->city;
        $data['post_code']              = $req->post_code;
        
        $data['sources_links']          = $req->sources_links;
        $data['confirm_by_moderator']   = $req->confirm_by_moderator;
        
        $data['description']            = $req->description;
        $data['status']                 = 'Pending';
        
        $data['date_added']             = date('Y-m-d H:i:s');
        $data['date_modified']          = date('Y-m-d H:i:s');
        
        $things_id = DB::table('things')->insertGetId($data);

        // INSERT TAGS
        if(!empty($req->tags)){
            foreach($req->tags as $tag){
                $tags_array['things_id']    = $things_id;
                $tags_array['name']         = $tag;
                $tags_array['status']       = 'Active';
                $result = DB::table('things_tags')->insert($tags_array);
            }
        }
        // INSERT TAGS

        // INSERT IMAGES
        if(isset($req->images)){
            foreach($req->images as $images){
                $prefix = time();
                $img_name = $prefix . '.jpeg';
                $image_path = public_path('uploads/things/') . $img_name;
                file_put_contents($image_path, base64_decode($images));
                
                $images_array['things_id'] = $things_id;
                $images_array['name'] = 'uploads/things/' . $img_name;
                $images_array['status'] = 'Active';
                $result = DB::table('things_images')->insert($images_array);
            }
        }
        // INSERT IMAGES
        
        $response["code"] = 200;
        $response["status"] = "success";
        $response["message"] = "A new thing added successfully.";
    } else {
      $response["code"] = 404;
      $response["status"] = "error";
      $response["message"] = "All fields are required.";
    }
    return response()
     ->json(array( 'status' => $response["status"], isset($response["message"]) ? 'message' : 'data' => isset($response["message"]) ? $response["message"] : $response["data"]))
     ->header('Content-Type', 'application/json');
  }
  /* THINGS ADD API */

  /* LIKE UNLIKE VENUES */
  public function venues_like_unlike(Request $req){
    if(isset($req->users_customers_id) && isset($req->venues_id)) {
      $users_likes   =  DB::table('users_likes')->where('post_id', $req->venues_id)->where('users_customers_id', $req->users_customers_id)->where('type', 'Venues')->get()->count();
      if($users_likes > 0){
        DB::table('users_likes')->where('post_id', $req->venues_id)->where('users_customers_id', $req->users_customers_id)->where('type', 'Venues')->delete();
        $response["code"] = 200;
        $response["status"] = "success";
        $response["message"] = 'Unliked';
      } else {
        DB::table('users_likes')->insertGetId(array('users_customers_id'=>$req->users_customers_id, 'post_id'=> $req->venues_id, 'type'=>'Venues'));
        $response["code"] = 200;
        $response["status"] = "success";
        $response["message"] = 'Liked';
      }
    } else {
      $response["code"] = 404;
      $response["status"] = "error";
      $response["message"] = "All fields are needed.";
    }

    return response()
      ->json(array( 'status' => $response["status"], isset($response["message"]) ? 'message' : 'data' => isset($response["message"]) ? $response["message"] : $response["data"]))
      ->header('Content-Type', 'application/json');
  }
  /* LIKE UNLIKE VENUES */
} 
